# Import the libraries to use time delays, send os commands and access GPIO pins
import RPi.GPIO as GPIO 
import time 
import os 
import mpd 

# Setup Variables
RedLedPin = 13 # Set pin number for "Standby" LED
GreenLedPin = 15 # Set pin number for "ON" LED
MainRelayPin = 11 # Set pin number for relay output
counter = 0 # counter for determining the time that has passed since MoOde player has stopped
SleepTime = 60 # The delay between each Status check, set to 60 = 1 minute to save CPU 
StandbyTime = 4 # The amount of time before "Standby" defined in multiples of SleepTime: StandbyTime*SleepTime (60*4 = 240sec = 4 minutes)

# Setup GPIO pins
GPIO.setmode(GPIO.BOARD) # Set pin numbering to board numbering 
GPIO.setup(MainRelayPin, GPIO.OUT) # Setup pin MainRelayPin as an output 
GPIO.setup(RedLedPin, GPIO.OUT) # Setup pin RedLedPin as an output 
GPIO.setup(GreenLedPin, GPIO.OUT) # Setup pin GreenLedPin as an output 

# Amplifier state control procedure
def AmpControl_ON(state):
	if state == True:
		GPIO.output(MainRelayPin, GPIO.HIGH)
		GPIO.output(RedLedPin, GPIO.LOW)
		GPIO.output(GreenLedPin, GPIO.HIGH)
	else:
		GPIO.output(MainRelayPin, GPIO.LOW)
		GPIO.output(RedLedPin, GPIO.HIGH)
		GPIO.output(GreenLedPin, GPIO.LOW)

# Setup MDPClient and connect to MPD on localhost
Client = mpd.MPDClient() # create client object 
Client.timeout = None
Client.idletimeout = None

while True:
	try:
		Client.connect("localhost", 6600) # connect to localhost:6600 
	except:
		continue
	break


# Set GPIO pins to their initial ON state
AmpControl_ON(True)

# main loop
while True:

	amp_on = GPIO.input(MainRelayPin)# Get status from Relay GPIO pin

    	if Client.status()['state'] == "play":
        	if not amp_on:
            		# Set GPIO pins to initial ON state
			#print "MPD state = play! Entering ON state"
			AmpControl_ON(True)
   			#print ("Amp is on = {0}".format(GPIO.input(MainRelayPin))) 

    	else: # Either stopped or paused
        	if amp_on:
			counter = 0 
			while counter < StandbyTime:
				time.sleep(SleepTime)
				counter = counter + 1
				#print ("Checking MPD status! {0} seconds have passed since last MPD was last playing.".format((counter)*SleepTime))
				if Client.status()['state'] == "play":
					break
				
			if Client.status()['state'] != "play": # Still stopped/paused after StandbyTime*SleepTime
				#print ("MPD has not been playing for {0} seconds! Entering standby!".format((counter)*SleepTime))
                		# Set GPIO pins to standby state
				AmpControl_ON(False)
				#print ("Amp is on = {0}".format(GPIO.input(MainRelayPin)))

     	#print "Waiting for change in MPD state......."
	Client.idle('player')
	#print "Change in MPD-player subsystem detected! continuing"

# Close connection to MPD (not used since the main loop never exits)
#Client.close() # send the close command
#Client.disconnect() # disconnect from the server
